@@ -1,3 +1,5 @@
+import datetime
+
 from django.conf import settings
 from django.db import models
 
@@ -125,7 +127,7 @@ class User(WordPressModel):
     password = models.CharField(max_length=64, db_column='user_pass')
     username = models.CharField(max_length=255, db_column='user_nicename')
     email = models.CharField(max_length=100, db_column='user_email')
-    url = models.URLField(max_length=100, db_column='user_url', verify_exists=False)
+    url = models.URLField(max_length=100, db_column='user_url', blank=True)
     date_registered = models.DateTimeField(auto_now_add=True, db_column='user_registered')
     activation_key = models.CharField(max_length=60, db_column='user_activation_key')
     status = models.IntegerField(default=0, choices=USER_STATUS_CHOICES, db_column='user_status')
@@ -164,7 +166,7 @@ class Link(WordPressModel):
     """
 
     id = models.IntegerField(db_column='link_id', primary_key=True)
-    url = models.URLField(max_length=255, verify_exists=False, db_column='link_url')
+    url = models.URLField(max_length=255, db_column='link_url')
     name = models.CharField(max_length=255, db_column='link_name')
     image = models.CharField(max_length=255, db_column='link_image')
     target = models.CharField(max_length=25, db_column='link_target')
@@ -214,13 +216,30 @@ class PostManager(WordPressManager):
         terms = terms if isinstance(terms, (list, tuple)) else [terms]
 
         try:
-            tx = Taxonomy.objects.filter(name=taxonomy, term__name__in=terms)
+            tx = Taxonomy.objects.filter(name=taxonomy, term__slug__in=terms)
             post_ids = TermTaxonomyRelationship.objects.filter(term_taxonomy__in=tx).values_list('object_id', flat=True)
 
             return Post.objects.published().filter(pk__in=post_ids)
         except Taxonomy.DoesNotExist:
             return Post.objects.none()
 
+    def from_path(self, path):
+
+        (ymd, slug) = path.strip('/').rsplit('/', 1)
+
+        start_date = datetime.datetime.strptime(ymd, "%Y/%m/%d")
+        end_date = start_date + datetime.timedelta(days=1) - datetime.timedelta(minutes=1)
+
+        params = {
+            'post_date__range': (start_date, end_date),
+            'slug': slug,
+        }
+
+        try:
+            return Post.objects.published().get(**params)
+        except Post.DoesNotExist:
+            pass  # fall through to return None
+
 
 class TermTaxonomyRelationship(WordPressModel):
 
@@ -356,7 +375,7 @@ class Comment(WordPressModel):
     # author fields
     author_name = models.CharField(max_length=255, db_column='comment_author')
     author_email = models.EmailField(max_length=100, db_column='comment_author_email')
-    author_url = models.URLField(verify_exists=False, db_column='comment_author_url')
+    author_url = models.URLField(blank=True, db_column='comment_author_url')
     author_ip = models.IPAddressField(db_column='comment_author_ip')
 
     # comment data
@@ -411,6 +430,7 @@ class Term(WordPressModel):
         return self.name
 
     @models.permalink
+
     def get_absolute_url(self):
         return ('wp_archive_term', (self.slug, ))
 
