@@ -95,7 +95,8 @@ class Archive(generic.dates.ArchiveIndexView):
     context_object_name = 'post_list'
     paginate_by = PER_PAGE
     template_name = 'wordpress/post_archive.html'
-
+    date_field = 'post_date'
+    
     def get(self, request, *args, **kwargs):
         p = request.GET.get('p', None)
         if p:
@@ -116,7 +117,7 @@ class TaxonomyArchive(generic.list.ListView):
     def get_context_data(self, **kwargs):
         context = super(TaxonomyArchive, self).get_context_data(**kwargs)
         context.update({
-            'tag': Term.objects.get(slug=self.kwargs['term']),
+            'tag': get_object_or_404(Term, slug=self.kwargs['term']),
             self.kwargs['taxonomy']: self.kwargs['term'],
         })
         return context
@@ -124,8 +125,7 @@ class TaxonomyArchive(generic.list.ListView):
     def get_queryset(self):
         taxonomy = TAXONOMIES.get(self.kwargs['taxonomy'], None)
         if taxonomy:
-            tag = get_object_or_404(Term, slug=self.kwargs['term'])
-            return Post.objects.term(tag.name, taxonomy=taxonomy).select_related()
+            return Post.objects.term(self.kwargs['term'], taxonomy=taxonomy).select_related()
 
 
 class TermArchive(generic.list.ListView):
